summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/classifiercodedocument.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/classifiercodedocument.h')
-rw-r--r--umbrello/umbrello/classifiercodedocument.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/umbrello/umbrello/classifiercodedocument.h b/umbrello/umbrello/classifiercodedocument.h
index 33aed6ad..dfdb4438 100644
--- a/umbrello/umbrello/classifiercodedocument.h
+++ b/umbrello/umbrello/classifiercodedocument.h
@@ -52,7 +52,7 @@ public:
/**
* Empty Constructor
*/
- ClassifierCodeDocument ( UMLClassifier * tqparent );
+ ClassifierCodeDocument ( UMLClassifier * parent );
/**
* Empty Destructor
@@ -79,12 +79,12 @@ public:
// some Utility methods
/**
* Return if the tqparent classifier is an interface
*/
bool parentIsInterface();
/**
* Return if the tqparent classifier is a class
*/
bool parentIsClass();
@@ -133,11 +133,11 @@ public:
*/
CodeClassFieldList getSpecificClassFields (CodeClassField::ClassFieldType cfType, bool isStatic, Uml::Visibility visibility);
/** Using the tqparent object's UML ID, find the corresponding
* codeclassfield object in this classifiercodedocument. Returns
* NULL if no such codeclassfield object exists in this document.
*
* @param id ID of the tqparent object
* @param role_id 0 for role A of the asssociation
* 1 for role B of the asssociation
* -1 if this is an attribute.
@@ -198,11 +198,11 @@ protected:
TextBlock * findCodeClassFieldTextBlockByTag (const TQString &tag);
// add the declaration text blocks for various classfields
- void declareClassFields (CodeClassFieldList & list , CodeGenObjectWithTextBlocks * tqparent);
+ void declareClassFields (CodeClassFieldList & list , CodeGenObjectWithTextBlocks * parent);
virtual void updateContent( ) = 0;
// force syncronization of child classfields to their tqparent objects
void syncClassFields( );
// IF the classifier object is modified, this will get called.
@@ -219,7 +219,7 @@ private:
// based on UMLRoles (e.g. derived from associations with other classifiers).
void updateAssociationClassFields ( UMLAssociationList &assocList );
// update code operations in this document using the tqparent classifier
void updateOperations( );
/**
@@ -237,7 +237,7 @@ private:
public slots:
/**
* Synchronize this document to the attributes/associations of the tqparent classifier.
*/
void addAttributeClassField(UMLClassifierListItem *at, bool syncToParentIfAdded = true);
void addAssociationClassField (UMLAssociation * assoc, bool syncToParentIfAdded = true);
@@ -79,12 +79,12 @@ public:
// some Utility methods
/**
- * Return if the tqparent classifier is an interface
+ * Return if the parent classifier is an interface
*/
bool parentIsInterface();
@@ -79,12 +79,12 @@ public:
bool parentIsInterface();
/**
- * Return if the tqparent classifier is a class
+ * Return if the parent classifier is a class
*/
bool parentIsClass();
@@ -133,11 +133,11 @@ public:
*/
CodeClassFieldList getSpecificClassFields (CodeClassField::ClassFieldType cfType, bool isStatic, Uml::Visibility visibility);
- /** Using the tqparent object's UML ID, find the corresponding
+ /** Using the parent object's UML ID, find the corresponding
* codeclassfield object in this classifiercodedocument. Returns
* NULL if no such codeclassfield object exists in this document.
@@ -133,11 +133,11 @@ public:
* NULL if no such codeclassfield object exists in this document.
*
- * @param id ID of the tqparent object
+ * @param id ID of the parent object
* @param role_id 0 for role A of the asssociation
* 1 for role B of the asssociation
@@ -198,11 +198,11 @@ protected:
virtual void updateContent( ) = 0;
- // force syncronization of child classfields to their tqparent objects
+ // force syncronization of child classfields to their parent objects
void syncClassFields( );
// IF the classifier object is modified, this will get called.
@@ -219,7 +219,7 @@ private:
// based on UMLRoles (e.g. derived from associations with other classifiers).
void updateAssociationClassFields ( UMLAssociationList &assocList );
- // update code operations in this document using the tqparent classifier
+ // update code operations in this document using the parent classifier
void updateOperations( );
/**
@@ -237,7 +237,7 @@ private:
public slots:
/**
- * Synchronize this document to the attributes/associations of the tqparent classifier.
+ * Synchronize this document to the attributes/associations of the parent classifier.
*/
void addAttributeClassField(UMLClassifierListItem *at, bool syncToParentIfAdded = true);